==> wrf_hydro_nwm_public-5.1.1.tar.gz: wrf_hydro_nwm_public-5.1.1/README.md <==
#  WRF-Hydro <img src=".github/images/wrf_hydro_symbol_logo_2017_09.png" width=100 align="left" />

[![Build Status](https://travis-ci.org/NCAR/wrf_hydro_nwm_public.svg?branch=v5.1.0)](https://travis-ci.org/NCAR/wrf_hydro_nwm_public)
[![Release](https://img.shields.io/github/release/NCAR/wrf_hydro_nwm_public.svg)](https://github.com/NCAR/wrf_hydro_nwm_public/releases/latest)
[![DOI](.github/badges/doi.svg)](https://ezid.cdlib.org/id/doi:10.5065/D6J38RBJ)

## Description
This is the code repository for [WRF-Hydro](https://ral.ucar.edu/projects/wrf_hydro).

WRF-Hydro is a community modeling system and framework for hydrologic modeling and model coupling.  In 2016 a configuration of WRF-Hydro was implemented as the [National Water Model](http://water.noaa.gov/about/nwm) (NWM) for the continental United States.

## Documentation
Documentation can be found on our [project website](https://ral.ucar.edu/projects/wrf_hydro/technical-description-user-guide).

## Resources and Support
For news and updates regarding the WRF-Hydro project please subscribe to our [email list](https://ral.ucar.edu/projects/wrf_hydro/subscribe).

For user support and general inquiries please use our [contact form](https://ral.ucar.edu/projects/wrf_hydro/contact).

If you have found a bug or would like to propose changes to the model code please refer to our [contributing guidelines](.github/CONTRIBUTING.md).

## Contributions
For more information on how to contribute to this project please refer to our [contributing guidelines](.github/CONTRIBUTING.md).

## License
The license and terms of use for this software can be found [here](LICENSE.txt).

## Acknowledgements
Funding support for the development and application of the WRF-Hydro system has been provided by:
- The National Science Foundation and the National Center for Atmospheric Research
- The National Oceanic and Atmospheric Administration (NOAA) Office of Water Prediction (OWP)
- The U.S. National Weather Service (NWS)
- The U.S. Department of Energy (DOE)
- The Colorado Water Conservation Board
- Baron Advanced Meteorological Services
- National Aeronautics and Space Administration (NASA)

==> wrf_hydro_nwm_public-5.2.0.tar.gz: wrf_hydro_nwm_public-5.2.0/README.md <==
#  WRF-Hydro® <img src=".github/images/wrf_hydro_symbol_logo_2017_09.png" width=100 align="left" />

[![Build Status](https://travis-ci.org/NCAR/wrf_hydro_nwm_public.svg?branch=master)](https://travis-ci.org/NCAR/wrf_hydro_nwm_public)
[![Release](https://img.shields.io/github/release/NCAR/wrf_hydro_nwm_public.svg)](https://github.com/NCAR/wrf_hydro_nwm_public/releases/latest)
[![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.3625237.svg)](https://doi.org/10.5281/zenodo.3625237)

## Description
This is the code repository for [WRF-Hydro®](https://ral.ucar.edu/projects/wrf_hydro).

WRF-Hydro is a community modeling system and framework for hydrologic modeling and model coupling.  In 2016 a configuration of WRF-Hydro was implemented as the [National Water Model](http://water.noaa.gov/about/nwm) (NWM) for the continental United States.

## Documentation
Documentation can be found on our [project website](https://ral.ucar.edu/projects/wrf_hydro/technical-description-user-guide).

## Resources and Support
For news and updates regarding the WRF-Hydro project please subscribe to our [email list](https://ral.ucar.edu/projects/wrf_hydro/subscribe).

For user support and general inquiries please use our [contact form](https://ral.ucar.edu/projects/wrf_hydro/contact).

If you have found a bug or would like to propose changes to the model code please refer to our [contributing guidelines](.github/CONTRIBUTING.md).

## Contributions
For more information on how to contribute to this project please refer to our [contributing guidelines](.github/CONTRIBUTING.md).

## License
The license and terms of use for this software can be found [here](LICENSE.txt).

## Acknowledgements
Funding support for the development and application of the WRF-Hydro system has been provided by:
- The National Science Foundation and the National Center for Atmospheric Research
- The National Oceanic and Atmospheric Administration (NOAA) Office of Water Prediction (OWP)
- The U.S. National Weather Service (NWS)
- The U.S. Department of Energy (DOE)
- The Colorado Water Conservation Board
- Baron Advanced Meteorological Services
- National Aeronautics and Space Administration (NASA)
